from django.apps import AppConfig


class OpenauthConfig(AppConfig):
    name = 'openauth'
    verbose_name = '统一认证'

    def ready(self):
        # 改写 LoginView 为 OpenAuthView
        from django.contrib.auth import views
        from openauth.views import OpenAuthView
        views.LoginView = OpenAuthView

        # 增加 user 合并社交账号 方法

        from django.contrib.auth.admin import UserAdmin

        def combine_users(self, request, qs):
            from .models import Account
            users = list(qs.order_by('id'))
            Account.objects.filter(user__in=qs).update(user=users[0])
            combines_uid_msg = ','.join(map(lambda x: x.username, users))
            self.message_user(request, '合并成功 %s => %s' % (combines_uid_msg, users[0].username))

        combine_users.short_description = '合并用户社交账号(以先创建的为主)'

        UserAdmin.actions = [combine_users, ]



from django.contrib import admin
from . import models as m


# Register your models here.

@admin.register(m.Account)
class AccountAdmin(admin.ModelAdmin):
    list_display = ('id', 'provider', 'uid', 'user', 'created')



# Generated by Django 2.2.6 on 2019-11-29 04:41

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('provider', models.CharField(max_length=128)),
                ('uid', models.CharField(max_length=256)),
                ('extra', models.TextField(blank=True, null=True)),
                ('created', models.DateTimeField()),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.db import models
from django.contrib.auth import get_user_model

User = get_user_model()


# Create your models here.

class Account(models.Model):
    """用户账号信息"""
    user = models.ForeignKey(User, blank=True, null=True, on_delete=models.SET_NULL)
    provider = models.CharField(max_length=128)
    uid = models.CharField(max_length=256)
    extra = models.TextField(blank=True, null=True)
    created = models.DateTimeField()



# coding: utf-8
from django.conf import settings

# The jwt secret key。If this key not set or set with '',
# OPENauth will get the key from redis
OPENAUTH_JWT_SECRET = getattr(settings, 'OPENAUTH_JWT_SECRET', '')
# 企业微信统一认证平台的url，注意这个 url 在使用中，会再增加跳转地址
QYWX_LOGIN_URL = getattr(
    settings, 'QYWX_LOGIN_URL',
    'https://open.taijihuabao.com/api/openauth/qywx?next=')

# OPENAUTH_REDIS_HOST = getattr(settings, 'OPENAUTH_REDIS_HOST', 'localhost')
# OPENAUTH_REDIS_PORT = getattr(settings, 'OPENAUTH_REDIS_PORT', '6379')
# OPENAUTH_REDIS_DB = getattr(settings, 'OPENAUTH_REDIS_DB', '9')
# OPENAUTH_REDIS_PASSWORD = getattr(settings, 'OPENAUTH_REDIS_PASSWORD', '')
